yakumo.nova.v2.floating_ip.Manager

Package yakumo :: Package nova :: Package v2 :: Module floating_ip :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for floating IPs in Compute API v2

Nested Classes | [hide private]
| resource_class Resource class for floating IPs in Compute API v2

Instance Methods | [hide private]
yakumo.nova.v2.floating_ip.Resource |
allocate(self, pool=`'``__UNDEF__``'`) Allocate a new floating IP | source code
[str] |
list_pools(self) List floating IP pools | source code
Inherited from `base.Manager`: `__init__`, `create`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``compute``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``create``'``,` `'``update``'``,` `'``delete``'``]``
| _json_resource_key = ``'``floating_ip``'``
| _json_resources_key = ``'``floating_ips``'``
| _url_resource_path = ``'``/os-floating-ips``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### allocate(self, pool=`'``__UNDEF__``'`) | source code
Allocate a new floating IP Parameters: `pool` (str) - Pool name Returns: yakumo.nova.v2.floating_ip.Resource Allocated floating IP address

### list_pools(self) | source code
List floating IP pools Returns: [str] Floating IP pool list

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('fixed_ip', 'fixed_ip', mapper.Noop), ('s
      erver', 'instance_id', mapper.Resource('nova.server')), ('ip', 'ip', m
      apper.Noop), ('pool', 'pool', mapper.Noop),]